# -*- coding: utf-8 -*-

# This code is a part of django-sunshine package: https://github.com/letuananh/sunshine
# :copyright: (c) 2013-2021 Le Tuan Anh <tuananh.ke@gmail.com>
# :license: MIT, see LICENSE for more details.

__author__ = "Le Tuan Anh"
__email__ = "tuananh.ke@gmail.com"
__copyright__ = "Copyright (c) 2013-2021, Le Tuan Anh <tuananh.ke@gmail.com>"
__credits__ = []
__license__ = "MIT License"
__description__ = "A bootstrap-based boilerplate for building modern Django websites"
__url__ = "https://github.com/letuananh/sunshine"
__issue__ = "https://github.com/letuananh/sunshine/issues/"
__keywords__ = ["bootstrap", "django", "portal"]
__maintainer__ = "Le Tuan Anh"
__version_major__ = "0.4.1"  # follow PEP-0440
__version__ = "{}a1".format(__version_major__)
__version_long__ = "{} - Alpha 1".format(__version_major__)
__status__ = "3 - Alpha"
# __status__ = "5 - Production/Stable"
