{% load static %}
{% comment %}
# This code is a part of sunshine package: https://github.com/letuananh/sunshine
# :copyright: (c) 2013-2021 Le Tuan Anh <tuananh.ke@gmail.com>
# :license: MIT, see LICENSE for more details.
{% endcomment %}

<!DOCTYPE html>
<html lang="en">

  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
    <meta name="description" content="">
    <meta name="author" content="">

    <title>{{ title| default:SUNSHINE_DEFAULT_TITLE }}</title>

    <!-- Custom fonts for this template-->
    {% block css %}
    <link href="{% static 'vendor/bootstrap/css/bootstrap.min.css' %}" rel="stylesheet">
    <link href="{% static 'vendor/faf/css/all.min.css' %}" rel="stylesheet" type="text/css">    
    {% endblock %}
    {% block style %}
    {% endblock %}
  </head>

  <body>
    {% block body %}
    <div class="container-fluid">
      {% block content %}
      {% endblock %}
    </div>
    {% endblock %}
    <!-- Bootstrap core JavaScript-->
    <script src="{% static 'vendor/jquery/jquery-3.5.1.min.js' %}"></script>
    <script src="{% static 'vendor/bootstrap/js/bootstrap.min.js' %}"></script>
    {% block script %}
    {% endblock %}
  </body>

</html>
