{% extends 'sunshine/base.html' %}
{% load static %}
{% comment %}
# This code is a part of sunshine package: https://github.com/letuananh/sunshine
# :copyright: (c) 2013-2021 Le Tuan Anh <tuananh.ke@gmail.com>
# :license: MIT, see LICENSE for more details.
{% endcomment %}

{% block content %}
<div>
  <div>
    Welcome back <span style="font-weight: bold;">{{ username }}</span>!
  </div>
</div>
{% endblock %}
